==> cinc-workstation-25.5.1084.tar.xz: cinc-workstation-25.5.1084/omnibus/omnibus.rb <==
#
# This file is used to configure the chef-workstation project. It contains
# some minimal configuration examples for working with Omnibus. For a full list
# of configurable options, please see the documentation for +omnibus/config.rb+.
#

# Build internally
# ------------------------------
# By default, Omnibus uses system folders (like +/var+ and +/opt+) to build and
# cache components. If you would to build everything internally, you can
# uncomment the following options. This will prevent the need for root
# permissions in most cases.
#
# Uncomment this line to change the default base directory to "local"
# -------------------------------------------------------------------
# base_dir './local'
#
# Alternatively you can tune the individual values
# ------------------------------------------------
# cache_dir     './local/omnibus/cache'
# git_cache_dir './local/omnibus/cache/git_cache'
# source_dir    './local/omnibus/src'
# build_dir     './local/omnibus/build'
# package_dir   './local/omnibus/pkg'
# package_tmp   './local/omnibus/pkg-tmp'

# Disable git caching
# ------------------------------
use_git_caching false

# Enable S3 asset caching
# ------------------------------
use_s3_caching true
s3_access_key  ENV["AWS_ACCESS_KEY_ID"]
s3_secret_key  ENV["AWS_SECRET_ACCESS_KEY"]
s3_bucket      "cinc-omnibus-cache"
s3_endpoint    "https://s3.osuosl.org"
s3_force_path_style true

build_retries 0
fetcher_retries 3
fetcher_read_timeout 120

# We limit this to 10 workers to eliminate transient timing issues in the
# way Ruby (and other components) compiles on some more esoteric *nixes.
workers 10

# Load additional software
# ------------------------------
# software_gems ['omnibus-software', 'my-company-software']
# local_software_dirs ['/path/to/local/software']

# Windows architecture defaults
# ------------------------------
arch = (ENV["OMNIBUS_WINDOWS_ARCH"] || "").downcase
windows_arch %w{x86 x64}.include?(arch) ? arch.to_sym : :x86

# Build in FIPS compatability mode
# ------------------------------
fips_mode (ENV["OMNIBUS_FIPS_MODE"] || "").casecmp("true") >= 0

==> cinc-workstation-25.12.1102.tar.xz: cinc-workstation-25.12.1102/omnibus/omnibus.rb <==
#
# This file is used to configure the chef-workstation project. It contains
# some minimal configuration examples for working with Omnibus. For a full list
# of configurable options, please see the documentation for +omnibus/config.rb+.
#

# Build internally
# ------------------------------
# By default, Omnibus uses system folders (like +/var+ and +/opt+) to build and
# cache components. If you would to build everything internally, you can
# uncomment the following options. This will prevent the need for root
# permissions in most cases.
#
# Uncomment this line to change the default base directory to "local"
# -------------------------------------------------------------------
# base_dir './local'
#
# Alternatively you can tune the individual values
# ------------------------------------------------
# cache_dir     './local/omnibus/cache'
# git_cache_dir './local/omnibus/cache/git_cache'
# source_dir    './local/omnibus/src'
# build_dir     './local/omnibus/build'
# package_dir   './local/omnibus/pkg'
# package_tmp   './local/omnibus/pkg-tmp'

# Disable git caching
# ------------------------------
use_git_caching false

# Enable S3 asset caching
# ------------------------------
use_s3_caching true
s3_access_key  ENV["AWS_ACCESS_KEY_ID"]
s3_secret_key  ENV["AWS_SECRET_ACCESS_KEY"]
s3_bucket      "cinc-omnibus-cache"
s3_endpoint    "https://s3.osuosl.org"
s3_force_path_style true

build_retries 0
fetcher_retries 3
fetcher_read_timeout 120

# We limit this to 10 workers to eliminate transient timing issues in the
# way Ruby (and other components) compiles on some more esoteric *nixes.
workers 10

# Load additional software
# ------------------------------
# software_gems ['omnibus-software', 'my-company-software']
# local_software_dirs ['/path/to/local/software']

# note, this is statically set in the omnibus-buildkite-plugin, you are always going to be forced to use internal sources. If you dont want internal sources, you must enable this to false.
use_internal_sources ENV.fetch("OMNIBUS_USE_INTERNAL_SOURCES", false)

# Windows architecture defaults
# ------------------------------
arch = (ENV["OMNIBUS_WINDOWS_ARCH"] || "").downcase
windows_arch %w{x86 x64}.include?(arch) ? arch.to_sym : :x86

# Build in FIPS compatability mode
# ------------------------------
fips_mode (ENV["OMNIBUS_FIPS_MODE"] || "").casecmp("true") >= 0
